@@ -1,21 +1,22 @@
-##' Create a multiple-choice response model and associated hyperparameters.
+##' Create a multiple-choice response model
 ##'
-##' This function instantiates a multiple-choice response
-##' model. Bayesian priors are only used to generate plausible random
-##' parameters.
+##' WARNING: This model is mostly not implemented.
 ##' 
-##' @param numOutcomes the number of possible outcomes
+##' This function instantiates a multiple-choice response
+##' model.
+##' 
+##' @param outcomes the number of possible outcomes
 ##' @param numChoices the number of choices available
-##' @param dimensions the number of dimensions
+##' @param factors the number of factors
 ##' @return an item model
 ##' @export
 ##' @author Jonathan Weeks <weeksjp@@gmail.com>
-rpf.mcm <- function(numOutcomes=2, numChoices=5, dimensions=1) {
+rpf.mcm <- function(outcomes=2, numChoices=5, factors=1) {
+  stop("Not implemented")
   guess.weight <- 20
   guessing <- (1/numChoices)
   new("rpf.mdim.mcm",
-      numOutcomes=numOutcomes, dimensions=dimensions,
-      numParam=numOutcomes * (dimensions + 2) - 1,
+      outcomes=outcomes, factors=factors,
       a.prior.sdlog=.5,
       c.prior.alpha=guess.weight*guessing+1,
       c.prior.beta=guess.weight*(1-guessing)+1)
@@ -28,15 +29,15 @@ setMethod("rpf.prob", signature(m="rpf.mdim.mcm", param="numeric",
           function(m, param, theta) {
             den <- NULL
             
-            a1 <- param[1:(m@dimensions*m@numOutcomes)]
-            b1 <- param[(m@dimensions*m@numOutcomes+1):
-                        ((m@dimensions+1)*m@numOutcomes)]
-            c1 <- param[-1:-((m@dimensions+1)*m@numOutcomes)]
+            a1 <- param[1:(m@factors*m@outcomes)]
+            b1 <- param[(m@factors*m@outcomes+1):
+                        ((m@factors+1)*m@outcomes)]
+            c1 <- param[-1:-((m@factors+1)*m@outcomes)]
             
             ##   Compute the denominator
-            for (k in 1:m@numOutcomes) {
-              tmp <- (k-1)*m@dimensions
-              tmp1 <- tmp+m@dimensions
+            for (k in 1:m@outcomes) {
+              tmp <- (k-1)*m@factors
+              tmp1 <- tmp+m@factors
               d <- exp((theta %*% a1[(tmp+1):tmp1])+b1[k])
               den <- cbind(den, d)
             }
@@ -44,15 +45,15 @@ setMethod("rpf.prob", signature(m="rpf.mdim.mcm", param="numeric",
 
             numPersons <- dim(theta)[1]
 
-            p <- array(dim=c(numPersons, m@numOutcomes))
+            p <- array(dim=c(numPersons, m@outcomes))
 
-            for (k in 1:m@numOutcomes) {
-              tmp <- (k-1)*m@dimensions
-              tmp1 <- tmp+m@dimensions
+            for (k in 1:m@outcomes) {
+              tmp <- (k-1)*m@factors
+              tmp1 <- tmp+m@factors
               if (k==1) {
                 cp <- (exp((theta %*% a1[(tmp+1):tmp1])+b1[k]))/den
               } else {
-                cp <- (exp((theta %*% a1[(tmp+1):tmp1])+b1[k])+c1[k-1]*(exp((theta %*% a1[1:m@dimensions])+b1[1])))/den
+                cp <- (exp((theta %*% a1[(tmp+1):tmp1])+b1[k])+c1[k-1]*(exp((theta %*% a1[1:m@factors])+b1[1])))/den
               }
               p[,k] <- cp
             }
@@ -61,10 +62,10 @@ setMethod("rpf.prob", signature(m="rpf.mdim.mcm", param="numeric",
 
 setMethod("rpf.rparam", signature(m="rpf.mdim.mcm"),
           function(m) {
-              a <- rlnorm(m@numOutcomes * m@dimensions,
+              a <- rlnorm(m@outcomes * m@factors,
                           meanlog=0, sdlog=m@a.prior.sdlog)
-              b <- sort(rnorm(m@numOutcomes))
-              c <- rbeta(m@numOutcomes-1, shape1=m@c.prior.alpha-2,
+              b <- sort(rnorm(m@outcomes))
+              c <- rbeta(m@outcomes-1, shape1=m@c.prior.alpha-2,
                          shape2=m@c.prior.beta-2)
               c(a=a,b=b,c=c)
           })
